@@ -4,39 +4,41 @@ data_location = os.path.join(__dir__, "verilog")
 src = "https://github.com/olofk/serv"
 
 # Module version
-version_str = "1.0.post135"
-version_tuple = (1, 0, 135)
+version_str = "1.1.0.post177"
+version_tuple = (1, 1, 0, 177)
 try:
     from packaging.version import Version as V
-    pversion = V("1.0.post135")
+    pversion = V("1.1.0.post177")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.0.post69"
-data_version_tuple = (1, 0, 69)
+data_version_str = "1.1.0.post35"
+data_version_tuple = (1, 1, 0, 35)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.0.post69")
+    pdata_version = V("1.1.0.post35")
 except ImportError:
     pass
-data_git_hash = "731ca8bb45f9182cd6d0ababcad3055a305fe298"
-data_git_describe = "v1.0-69-g731ca8b"
+data_git_hash = "4ddd154b249f46522f164aa9a49cce3edfafe03c"
+data_git_describe = "1.1.0-35-g4ddd154"
 data_git_msg = """\
-commit 731ca8bb45f9182cd6d0ababcad3055a305fe298
-Author: Bruno Flores <bruno@brunoflores.com.br>
-Date:   Sat Oct 24 12:04:41 2020 +0000
+commit 4ddd154b249f46522f164aa9a49cce3edfafe03c
+Author: Wadood <82087831+Abdulwadoodd@users.noreply.github.com>
+Date:   Tue May 17 12:11:56 2022 +0500
 
-    Allow for a configurable toolchain prefix.
+    Nexys 2 Board support
+    
+    Added nexys 2 target support for servant
 
 """
 
 # Tool version info
-tool_version_str = "0.0.post66"
-tool_version_tuple = (0, 0, 66)
+tool_version_str = "0.0.post142"
+tool_version_tuple = (0, 0, 142)
 try:
     from packaging.version import Version as V
-    ptool_version = V("0.0.post66")
+    ptool_version = V("0.0.post142")
 except ImportError:
     pass
 
